using OpenXmlWriter.Packaging;

namespace OpenXmlWriter.Packaging
{
	public class CustomXmlPart : OpenXmlPart
	{
    private const string PartRelationshipType =
      "http://schemas.openxmlformats.org/officeDocument/2006/relationships/customXml";

    private const string PartName = "item";
    private const string PartPath = "customXML";
    private const string PartExtension = ".xml";
    public const string PartContentType = "application/xml";
    private string _targetPath;

    public override void Initialize(OpenXmlPackage openXmlPackage, OpenXmlPartContainer openXmlPartContainer)
    {
      base.Initialize(openXmlPackage, openXmlPartContainer);
      _targetPath = CreateUniquePath();

      _contentType = new ContentType(_targetPath, PartContentType, true);
    }

    private string CreateUniquePath()
    {
      return PartPath + "/" + PartName + CustomXmlPartHelper.GetNextId() + PartExtension;
    }

    public override string RelationshipType
    {
      get
      {
        return PartRelationshipType;
      }
    }

    public override ContentType ContentType
    {
      get
      {
        return _contentType;
      }
    }

    public override void AddTo(OpenXmlPartCollection parts)
    {
      parts.Add(_targetPath, this);
    }

    public override string TargetPath
    {
      get
      {
        return _targetPath;
      }
    }
  }
}
